[][src]Struct ilp_node::PrometheusConfig

pub struct PrometheusConfig {
    pub bind_address: SocketAddr,
    pub histogram_window: u64,
    pub histogram_granularity: u64,
}

Configuration for Prometheus metrics collection.

Fields

bind_address: SocketAddr

IP address and port to host the Prometheus endpoint on.

histogram_window: u64

Amount of time, in milliseconds, that the node will collect data points for the Prometheus histograms. Defaults to 300000ms (5 minutes).

histogram_granularity: u64

Granularity, in milliseconds, that the node will use to roll off old data. For example, a value of 1000ms (1 second) would mean that the node forgets the oldest 1 second of histogram data points every second. Defaults to 10000ms (10 seconds).